@@ -96,7 +96,7 @@ QHash<Utils::Id, PuppetCreator::PuppetType> PuppetCreator::m_qml2PuppetForKitPup
 
 QByteArray PuppetCreator::qtHash() const
 {
-    QtSupport::BaseQtVersion *currentQtVersion = QtSupport::QtKitAspect::qtVersion(m_target->kit());
+    QtSupport::QtVersion *currentQtVersion = QtSupport::QtKitAspect::qtVersion(m_target->kit());
     if (currentQtVersion) {
         return QCryptographicHash::hash(currentQtVersion->dataPath().toString().toUtf8(),
                                         QCryptographicHash::Sha1)
@@ -108,7 +108,7 @@ QByteArray PuppetCreator::qtHash() const
 
 QDateTime PuppetCreator::qtLastModified() const
 {
-    QtSupport::BaseQtVersion *currentQtVersion = QtSupport::QtKitAspect::qtVersion(m_target->kit());
+    QtSupport::QtVersion *currentQtVersion = QtSupport::QtKitAspect::qtVersion(m_target->kit());
     if (currentQtVersion)
         return currentQtVersion->libraryPath().lastModified();
 
@@ -132,8 +132,9 @@ QDateTime PuppetCreator::puppetSourceLastModified() const
     };
 
     QDateTime lastModified;
-    foreach (const QString directoryPath, sourceDirectoryPaths) {
-        foreach (const QFileInfo fileEntry, QDir(directoryPath).entryInfoList()) {
+    for (const QString &directoryPath : sourceDirectoryPaths) {
+        const QFileInfoList fileEntrys = QDir(directoryPath).entryInfoList();
+        for (const QFileInfo &fileEntry : fileEntrys) {
             const QDateTime filePathLastModified = fileEntry.lastModified();
             if (lastModified < filePathLastModified)
                 lastModified = filePathLastModified;
@@ -148,7 +149,7 @@ bool PuppetCreator::useOnlyFallbackPuppet() const
 #ifndef QMLDESIGNER_TEST
     if (!m_target || !m_target->kit()->isValid())
         qWarning() << "Invalid kit for QML puppet";
-    return m_designerSettings.value(DesignerSettingsKey::USE_DEFAULT_PUPPET).toBool()
+    return QmlDesignerPlugin::settings().value(DesignerSettingsKey::USE_DEFAULT_PUPPET).toBool()
             || m_target == nullptr || !m_target->kit()->isValid();
 #else
     return true;
@@ -187,9 +188,6 @@ PuppetCreator::PuppetCreator(ProjectExplorer::Target *target, const Model *model
     : m_target(target)
     , m_availablePuppetType(FallbackPuppet)
     , m_model(model)
-#ifndef QMLDESIGNER_TEST
-    , m_designerSettings(QmlDesignerPlugin::instance()->settings())
-#endif
 {
 }
 
@@ -231,7 +229,7 @@ QProcessUniquePointer PuppetCreator::puppetProcess(
                      processFinishCallback);
 
 #ifndef QMLDESIGNER_TEST
-    QString forwardOutput = m_designerSettings.value(DesignerSettingsKey::
+    QString forwardOutput = QmlDesignerPlugin::settings().value(DesignerSettingsKey::
         FORWARD_PUPPET_OUTPUT).toString();
 #else
     QString forwardOutput("all");
@@ -264,7 +262,7 @@ QProcessUniquePointer PuppetCreator::puppetProcess(
     }
 
 #ifndef QMLDESIGNER_TEST
-    QString debugPuppet = m_designerSettings.value(DesignerSettingsKey::
+    QString debugPuppet = QmlDesignerPlugin::settings().value(DesignerSettingsKey::
         DEBUG_PUPPET).toString();
 #else
     QString debugPuppet("all");
@@ -371,10 +369,10 @@ static Utils::FilePath pathForBinPuppet(ProjectExplorer::Target *target)
     if (!target || !target->kit())
         return {};
 
-    QtSupport::BaseQtVersion *currentQtVersion = QtSupport::QtKitAspect::qtVersion(target->kit());
+    QtSupport::QtVersion *currentQtVersion = QtSupport::QtKitAspect::qtVersion(target->kit());
 
     if (currentQtVersion)
-        return currentQtVersion->binPath() / Utils::HostOsInfo::withExecutableSuffix("qml2puppet");
+        return currentQtVersion->binPath().pathAppended("qml2puppet").withExecutableSuffix();
 
     return {};
 }
@@ -414,7 +412,7 @@ QString PuppetCreator::defaultPuppetToplevelBuildDirectory()
 QString PuppetCreator::qmlPuppetToplevelBuildDirectory() const
 {
 #ifndef QMLDESIGNER_TEST
-    QString puppetToplevelBuildDirectory = m_designerSettings.value(
+    QString puppetToplevelBuildDirectory = QmlDesignerPlugin::settings().value(
                 DesignerSettingsKey::PUPPET_TOPLEVEL_BUILD_DIRECTORY).toString();
     if (puppetToplevelBuildDirectory.isEmpty())
         return defaultPuppetToplevelBuildDirectory();
@@ -434,7 +432,7 @@ QString PuppetCreator::qmlPuppetDirectory(PuppetType puppetType) const
     if (puppetType == BinPathPuppet)
         return pathForBinPuppet(m_target).toFileInfo().absoluteDir().canonicalPath();
 
-    return qmlPuppetFallbackDirectory(m_designerSettings);
+    return qmlPuppetFallbackDirectory(QmlDesignerPlugin::settings());
 #else
     return QString();
 #endif
@@ -482,17 +480,17 @@ QProcessEnvironment PuppetCreator::processEnvironment() const
     if (QTC_GUARD(m_target)) {
         if (!useOnlyFallbackPuppet() || m_availablePuppetType == BinPathPuppet) {
             m_target->kit()->addToBuildEnvironment(environment);
-            const QtSupport::BaseQtVersion *qt = QtSupport::QtKitAspect::qtVersion(m_target->kit());
+            const QtSupport::QtVersion *qt = QtSupport::QtKitAspect::qtVersion(m_target->kit());
             if (QTC_GUARD(qt)) { // Kits without a Qt version should not have a puppet!
                 // Update PATH to include QT_HOST_BINS
-                const Utils::FilePath qtBinPath = qt->hostBinPath();
-                environment.prependOrSetPath(qtBinPath.toString());
+                environment.prependOrSetPath(qt->hostBinPath());
             }
         }
     }
     environment.set("QML_BAD_GUI_RENDER_LOOP", "true");
     environment.set("QML_PUPPET_MODE", "true");
     environment.set("QML_DISABLE_DISK_CACHE", "true");
+    environment.set("QMLPUPPET_RENDER_EFFECTS", "true");
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     if (!environment.hasKey("QT_SCREEN_SCALE_FACTORS") && !environment.hasKey("QT_SCALE_FACTOR")
             && QApplication::testAttribute(Qt::AA_EnableHighDpiScaling))
@@ -502,8 +500,14 @@ QProcessEnvironment PuppetCreator::processEnvironment() const
         environment.set("QT_AUTO_SCREEN_SCALE_FACTOR", "1");
 
 #ifndef QMLDESIGNER_TEST
-    const QString controlsStyle = m_designerSettings.value(DesignerSettingsKey::
+    const QString controlsStyle = QmlDesignerPlugin::settings().value(DesignerSettingsKey::
             CONTROLS_STYLE).toString();
+
+    const bool smoothRendering = QmlDesignerPlugin::settings().value(DesignerSettingsKey::SMOOTH_RENDERING)
+                                     .toBool();
+
+    if (smoothRendering)
+        environment.set("QMLPUPPET_SMOOTH_RENDERING", "true");
 #else
     const QString controlsStyle;
 #endif
@@ -532,10 +536,25 @@ QProcessEnvironment PuppetCreator::processEnvironment() const
     QmlDesigner::Import import = QmlDesigner::Import::createLibraryImport("QtQuick3D", "1.0");
     if (m_model->hasImport(import, true, true))
         environment.set("QMLDESIGNER_QUICK3D_MODE", "true");
-    import = QmlDesigner::Import::createLibraryImport("QtCharts", "2.0");
+
+    import = QmlDesigner::Import::createLibraryImport("QtQuick3D.Particles3D", "1.0");
     if (m_model->hasImport(import, true, true))
+        environment.set("QMLDESIGNER_QUICK3D_PARTICLES3D_MODE", "true");
+
+    import = QmlDesigner::Import::createLibraryImport("QtCharts", "2.0");
+    if (m_model->hasImport(import, true, true)) {
         environment.set("QMLDESIGNER_FORCE_QAPPLICATION", "true");
-    environment.set("QT_QUICK3D_DISABLE_PARTICLE_SYSTEMS", "1");
+    } else if (m_target) {
+        auto bs = qobject_cast<QmlProjectManager::QmlBuildSystem *>(m_target->buildSystem());
+        if (bs && bs->widgetApp())
+            environment.set("QMLDESIGNER_FORCE_QAPPLICATION", "true");
+    }
+
+    bool particlemode = QmlDesigner::QmlDesignerPlugin::settings().value("particleMode").toBool();
+    if (!particlemode)
+        environment.set("QT_QUICK3D_DISABLE_PARTICLE_SYSTEMS", "1");
+    else
+        environment.set("QT_QUICK3D_EDITOR_PARTICLE_SYSTEMS", "1");
 #endif
 
     QStringList importPaths = m_model->importPaths();
@@ -592,7 +611,7 @@ QString PuppetCreator::buildCommand() const
 
 QString PuppetCreator::qmakeCommand() const
 {
-    QtSupport::BaseQtVersion *currentQtVersion = QtSupport::QtKitAspect::qtVersion(m_target->kit());
+    QtSupport::QtVersion *currentQtVersion = QtSupport::QtKitAspect::qtVersion(m_target->kit());
     if (currentQtVersion)
         return currentQtVersion->qmakeFilePath().toString();
 
@@ -679,7 +698,7 @@ static bool nonEarlyQt5Version(const QtSupport::QtVersionNumber &currentQtVersio
 
 bool PuppetCreator::qtIsSupported() const
 {
-    QtSupport::BaseQtVersion *currentQtVersion = QtSupport::QtKitAspect::qtVersion(m_target->kit());
+    QtSupport::QtVersion *currentQtVersion = QtSupport::QtKitAspect::qtVersion(m_target->kit());
 
     return currentQtVersion
             && currentQtVersion->isValid()
